@@ -3,9 +3,11 @@ import dataclasses as dc
 import datetime
 import enum
 import types
-import typing as tp
+import typing
+import typing as tp  # pylint: disable=reimported
 from pathlib import Path
 
+import django.db  # pylint: disable=unused-import
 from django.db import models
 
 from ._decorator import BACKEND_LINKER
@@ -13,12 +15,15 @@ from ._decorator import django_model
 from ._inspect_dataclass import InspectDataclass
 from ._util import public_name
 
+# 2023-Q1: sphinx has a bug regarding adjusting the signature for attributes,
+# hence I need fully qualified imports for typing and django.db
+
 __all__ = ["CreateDjangoModel", "create_django_model"]
 
 
 @dc.dataclass(frozen=True)
 class CreateDjangoModel(InspectDataclass):
-    alt_field_type: "dict[str, type[models.Field[tp.Any, tp.Any]]]" = dc.field(
+    alt_field_type: "dict[str, type[django.db.models.Field[typing.Any, typing.Any]]]" = dc.field(
         default_factory=dict
     )
 
@@ -41,7 +46,7 @@ class CreateDjangoModel(InspectDataclass):
         fields = {}
         for field in dc.fields(self.dataclass):
             try:
-                django_field = self.alt_field_type[field.name]
+                django_field = self.alt_field_type.pop(field.name)
                 opts: dict[str, tp.Any] = {}
             except KeyError:
                 django_field, opts = self.django_field_precursor(field.type)
@@ -60,6 +65,11 @@ class CreateDjangoModel(InspectDataclass):
             raise RuntimeError(
                 f"unconsumed extra kwgs ({extra_kwgs}) found for {self.dataclass}, please adjust!"
             )
+        if self.alt_field_type:
+            raise RuntimeError(
+                f"unused alt_field_type ({self.alt_field_type}) found for {self.dataclass}, please adjust!"
+            )
+
         return fields
 
     def generate_meta(
@@ -148,7 +158,7 @@ class CreateDjangoModel(InspectDataclass):
 def create_django_model(
     dataclass: type,
     alt_field_type: "dict[str, type[models.Field[tp.Any, tp.Any]]] | None" = None,
-) -> type[models.Model]:
+) -> "type[models.Model]":
     alt_field_type = alt_field_type or {}
     CreateDjangoModel(dataclass, alt_field_type)
     return django_model(dataclass)
