@@ -5,6 +5,7 @@ import types
 import typing as tp
 from pathlib import Path
 
+from django.conf import settings
 from django.core.files import File
 from django.db import models
 
@@ -19,11 +20,18 @@ class DjangoStore:
     identifier: str
 
     def dump(self, dc_obj: tp.Any) -> "tuple[models.Model, bool]":
-        kwgs, m2m = self.dataclass_to_django(dc_obj)
+        kwgs, m2m, update_origin = self.dataclass_to_django(dc_obj)
         identifying, defaults = self._split_off_pk(dc_obj, kwgs)
         dj_obj, created = self.backend_manager(dc_obj).update_or_create(
             **identifying, defaults=defaults
         )
+        for key, fct in update_origin.items():
+            try:
+                setattr(dc_obj, key, fct(getattr(dj_obj, key)))
+            except dc.FrozenInstanceError as err:
+                raise RuntimeError(
+                    f"cannot change attribute {key} due to dataclass being frozen, remove field or unfreeze!"
+                ) from err
 
         for key, vals in m2m.items():
             # remove old ones
@@ -49,6 +57,7 @@ class DjangoStore:
         model = django_model(dc_obj)
         kwgs = {}
         m2m = {}
+        update_origin = {}
         for field in dc.fields(dc_obj):
             key = field.name
             val = getattr(dc_obj, key)
@@ -57,10 +66,21 @@ class DjangoStore:
             if isinstance(val, enum.Enum):
                 val = val.value
             if isinstance(val, Path) and val is not None:
-                val = File(
-                    open(val, "rb"),  # pylint: disable=consider-using-with
-                    name=val.name,
-                )
+
+                def get_file(path: Path) -> "File[tp.Any]":
+                    return File(
+                        open(path, "rb"),  # pylint: disable=consider-using-with
+                        name=path.name,
+                    )
+
+                try:
+                    val = get_file(val)
+                    update_origin[key] = lambda x: Path(x.url)
+                except FileNotFoundError as err:
+                    loc = Path(settings.MEDIA_ROOT) / val.relative_to(val.root)
+                    if not loc.exists():
+                        raise err
+                    val = get_file(loc)
 
             # pylint: disable=protected-access
             dj_model = model._meta.get_field(key)
@@ -69,7 +89,7 @@ class DjangoStore:
             else:
                 kwgs[key] = val
 
-        return kwgs, m2m
+        return kwgs, m2m, update_origin
 
     def django_to_dataclass(self, dj_obj: models.Model) -> tp.Any:
         dataclass = BACKEND_LINKER.backend_to_dc[type(dj_obj)]
@@ -123,5 +143,5 @@ class DjangoStore:
         ident_keys = InspectDataclass(dc_obj).get_identifying_parameter()
         return (
             {key: kwgs[key] for key in kwgs.keys() & ident_keys},
-            {key: kwgs[key] for key in kwgs.keys() ^ ident_keys},
+            {key: kwgs[key] for key in kwgs.keys() ^ ident_keys if key in kwgs},
         )
