@@ -27,6 +27,8 @@ class SyncStore:
         if hasattr(obj, "pre_save"):
             obj.pre_save()
         _, created = self.impl.dump(obj)
+        if hasattr(obj, "post_save"):
+            obj.post_save(created)
         return created  # type: ignore
 
     def load_all(self, dataclass: type[T], **filter_kwgs: tp.Any) -> tp.Iterator[T]:
